package Zim::Formats::Pod;

use strict;

our $VERSION = 0.01;

our %TAG_ALIASES = ( # FIXME what to use for strike ??
	B         => 'bold',
	C         => 'verbatim',
	I         => 'italic',
	L         => 'link',
	U         => 'underline',
	bold      => 'B',
	verbatim  => 'C',
	italic    => 'I',
	link      => 'L',
	underline => 'U',
);

=head1 NAME

... - simple module

=head1 SYNOPSIS

FIXME simple code example

=head1 DESCRIPTION

FIXME descriptve text

=head1 EXPORT

None by default.

=head1 METHODS

=over 4

=item C<new()>

Simple constructor

=cut

sub new {
}


1;

__END__

=back

=head1 AUTHOR

Jaap Karssenberg (Pardus) E<lt>pardus@cpan.orgE<gt>

Copyright (c) 2005 Jaap G Karssenberg. All rights reserved.
This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

=head1 SEE ALSO

=cut

